OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Додато у омиљено",
    "Removed from favorites" : "Избачено из омиљених",
    "You added {file} to your favorites" : "Додали сте {file} у омиљене",
    "You removed {file} from your favorites" : "Избацили сте {file} из омиљених",
    "Favorites" : "Омиљени",
    "File changes" : "Измене над фајлом",
    "Created by {user}" : "Направио {user}",
    "Changed by {user}" : "Изменио {user}",
    "Deleted by {user}" : "Обрисао {user}",
    "Restored by {user}" : "Повратио {user}",
    "Renamed by {user}" : "Преименовао {user}",
    "Moved by {user}" : "Померио {user}",
    "\"remote account\"" : "„удаљени налог”",
    "You created {file}" : "Направили сте {file}",
    "You created an encrypted file in {file}" : "Направили сте шифровани фајл {file}",
    "{user} created {file}" : "{user} је направио {file}",
    "{user} created an encrypted file in {file}" : "{user} је направио шифровани фајл {file}",
    "{file} was created in a public folder" : "{file} је направљен у јавној фасцикли",
    "You changed {file}" : "Изменили сте {file}",
    "You changed an encrypted file in {file}" : "Изменили сте шифровани фајл {file}",
    "{user} changed {file}" : "{user} је изменио {file}",
    "{user} changed an encrypted file in {file}" : "{user} је изменио шифровани фајл {file}",
    "You deleted {file}" : "Обрисали сте {file}",
    "You deleted an encrypted file in {file}" : "Обрисали сте шифровани фајл {file}",
    "{user} deleted {file}" : "{user} је обрисао {file}",
    "{user} deleted an encrypted file in {file}" : "{user} је обрисао шифровани фајл {file}",
    "You restored {file}" : "Повратили сте {file}",
    "{user} restored {file}" : "{user} је повратио {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Променили сте име фајла {oldfile} (скривено) на {newfile} (скривено)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Променили сте име фајла {oldfile} (скривено) на {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Променили сте име фајла {oldfile} на {newfile} (скривено)",
    "You renamed {oldfile} to {newfile}" : "Преименовали сте {oldfile} на {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} је променио име фајла {oldfile} (скривено) на {newfile} (скривено)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} је променио име фајла {oldfile} (скривено) на {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} је променио име фајла {oldfile} на {newfile} (скривено)",
    "{user} renamed {oldfile} to {newfile}" : "{user} је преименовао {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Померили сте {oldfile} на {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} је померио {oldfile} на {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Фајл је додат или избрисан из Ваших <strong>омиљених</strong>",
    "Files" : "Фајлови",
    "A file or folder has been <strong>changed</strong>" : "Фајл или фасцикла су <strong>измењени</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Омиљени фајл или фасцикла су <strong>измењени</strong>",
    "Failed to authorize" : "Није успело добијање дозволе",
    "Invalid folder path" : "Неисправна путања фолдера",
    "Folder not found" : "Није пронађен фолдер",
    "The file cannot be found" : "Фајл не може да се пронађе",
    "The destination path does not exist: %1$s" : "Путања одредишта не постоји: %1$s",
    "You do not have permission to create a file at the specified location" : "Немате дозволу да креирате фајл на наведеној локацији",
    "The file could not be converted." : "Фајл није могао да се конвертује.",
    "Could not get relative path to converted file" : "Није могла да се преузме релативна путања до конвертованог фајла",
    "Limit must be a positive integer." : "Граница мора бити позитиван цео број.",
    "The replacement character may only be a single character." : "Карактер замене мора бити само један карактер.",
    "Filename sanitization already started." : "Пречишћавање имена фајла је већ започето.",
    "No filename sanitization in progress." : "Није у току ниједно пречишћавање имена фајла.",
    "Favorite files" : "Омиљени фајлови",
    "No favorites" : "Нема омиљених",
    "More favorites" : "Још омиљених",
    "Accept" : "Прихвати",
    "Reject" : "Одбаци",
    "Incoming ownership transfer from {user}" : "Надолазећи пренос власништва од корисника {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Да ли желите да прихватите {path}?\n\nПажња: После прихватања, процес трансфера може потрајати и до 1h.",
    "Ownership transfer denied" : "Пренос власништва је одбијен",
    "Your ownership transfer of {path} was denied by {user}." : "Корисник {user} је одбио ваш пренос власништва над {path}.",
    "Ownership transfer failed" : "Пренос власништва није успео",
    "Your ownership transfer of {path} to {user} failed." : "Ваш пренос власништва {path} на корисника {user} није успео.",
    "The ownership transfer of {path} from {user} failed." : "Пренос власништва {path} на корисника {user} није успео.",
    "Ownership transfer done" : "Пренос власништва завршен",
    "Your ownership transfer of {path} to {user} has completed." : "Ваш пренос власништва {path} на корисника {user} завршен.",
    "The ownership transfer of {path} from {user} has completed." : "Пренос власништва {path} на корисника {user} завршен.",
    "in %s" : "за %s",
    "Transferred from %1$s on %2$s" : "Пренесено са %1$s на %2$s",
    "File Management" : "Управљање фајловима",
    "Home" : "Почетна",
    "Target folder does not exist any more" : "Одредишна фасцикла више не постоји",
    "Reload current directory" : "Поново учитај текући директоријум",
    "Go to the \"{dir}\" directory" : "Иди у „{dir}” дирекотријум",
    "Current directory path" : "Путања текућег директоријума",
    "Your have used your space quota and cannot upload files anymore" : "Искористили сте квоту простора и више не можете да отпремате фајлове",
    "You do not have permission to upload or create files here." : "Немате дозволу да овде отпремите или креирате фајлове.",
    "Drag and drop files here to upload" : "Да отпремите, превуците и отпустите фајлове овде",
    "Favorite" : "Омиљено",
    "Back" : "Назад",
    "Toggle selection for file \"{displayName}\"" : "Укљ./искљ. избор за фајл „{displayName}”",
    "Toggle selection for folder \"{displayName}\"" : "Укљ./искљ. избор за фолдер „{displayName}”",
    "File is loading" : "Фајл се учитава",
    "Folder is loading" : "Фолдер се учитава",
    "Filename" : "Назив фајла",
    "Folder name" : "Назив фасцикле",
    "This node is unavailable" : "Овај чвор није доступан",
    "Another entry with the same name already exists." : "Већ постоји ставка са истим именом.",
    "Invalid filename." : "Неисправно име фајла.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}” је промењено на „{newName}”",
    "Rename file" : "Промени назив фајла",
    "Folder" : "Фасцикла",
    "Unknown file type" : "Непознат тип фајла",
    "{ext} image" : "{ext} слика",
    "{ext} video" : "{ext} видео",
    "{ext} audio" : "{ext} аудио",
    "{ext} text" : "{ext} текст",
    "Pending" : "На чекању",
    "Unknown date" : "Непознат датум",
    "Clear filter" : "Очисти филтер",
    "Modified" : "Измењен",
    "Search everywhere" : "Претражи свуда",
    "Type" : "Тип",
    "Active filters" : "Активни филтери",
    "Remove filter" : "Уклони филтер",
    "Appearance" : "Изглед",
    "Show hidden files" : "Прикажи скривене фајлове",
    "Show file type column" : "Прикажи колону са типом фајла",
    "Show file extensions" : "Прикажи екстензије фајла",
    "Crop image previews" : "Опсецање прегледа слика",
    "General" : "Опште",
    "Sort favorites first" : "Сортирај прво омиљене",
    "Sort folders before files" : "Поређај фолдере испред фајлова",
    "Default view" : "Подразумевани поглед",
    "All files" : "Сви фајлови",
    "Personal files" : "Лични фајлови",
    "Additional settings" : "Додатне поставке",
    "Actions" : "Радње",
    "File actions" : "Фајл акције",
    "Selection" : "Избор",
    "Select all files" : "Изабери све фајлове",
    "Deselect all" : "Поништи цео избор",
    "Select or deselect" : "Изабери или уклони избор",
    "Select a range" : "Изабери опсег",
    "Navigation" : "Навигација",
    "Go to parent folder" : "Иди на фолдер родитељ",
    "Go to file above" : "Иди на фајл изнад",
    "Go to file below" : "Иди на фајл испод",
    "Go left in grid" : "Иди на лево у мрежи",
    "Go right in grid" : "Иди на десно у мреж",
    "View" : "Погледај",
    "Toggle grid view" : "Укључи/искључи приказ мреже",
    "Open file sidebar" : "Отвори бочну траку за фајл",
    "Show those shortcuts" : "Прикажи те пречице",
    "Warnings" : "Упозорења",
    "Warn before changing a file extension" : "Упозори пре измене екстензије фајла",
    "WebDAV URL" : "WebDAV URL",
    "How to access files using WebDAV" : "Како да приступите фајловима преко WebDAV протокола",
    "Total rows summary" : "Резиме укупног броја редова",
    "Toggle selection for all files and folders" : "Укљ./искљ. избор за све фајлове и фолдере",
    "Name" : "Назив",
    "File type" : "Тип фајла",
    "Size" : "Величина",
    "{displayName}: failed on some elements" : "{displayName}: није успело на неким елементима",
    "{displayName}: done" : "{displayName}: завршено",
    "{displayName}: failed" : "{displayName}: није успело",
    "(selected)" : "(изабрано)",
    "List of files and folders." : "Листа фајлова и фолдера.",
    "You have used your space quota and cannot upload files anymore." : "Искористили сте квоту простора и више не можете да отпремате фајлове.",
    "Column headers with buttons are sortable." : "Заглавља колона са дугмићима могу да се соритрају.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
    "File not found" : "Фајл није нађен",
    "_{count} selected_::_{count} selected_" : ["изабран је {count}","изабрана су {count}","изабрано је {count}"],
    "Search everywhere …" : "Претражи свуда …",
    "Search here …" : "Претражи овде …",
    "Search scope options" : "Опције опсега претраге",
    "Search here" : "Претражи овде",
    "{usedQuotaByte} used" : "{usedQuotaByte} искоришћено",
    "{used} of {quota} used" : "{used} од {quota} искоришћено",
    "{relative}% used" : "{relative}% искоришћено",
    "Could not refresh storage stats" : "Статистике складишта нису могле да се освеже",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
    "Storage information" : "Информације о складишту",
    "Storage quota" : "Квота складишта",
    "New folder" : "Нова фасцикла",
    "Create new folder" : "Направи нову фасциклу",
    "This name is already in use." : "Ово име се већ користи.",
    "Create" : "Направи",
    "Files starting with a dot are hidden by default" : "Фајлови који почињу тачком су подразумевано скривени",
    "Failed to start filename sanitization." : "Није успело покретање пречишћавање имена фајла.",
    "Failed to refresh filename sanitization status." : "Није успело освежавање статуса пречишћавања имена фајла.",
    "Filename sanitization in progress." : "Пречишћавање имена фајла је у току.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Тренутно је већ обрађено {processedUsers} од {totalUsers} налога.",
    "Preparing …" : "Припрема се …",
    "Refresh" : "Освежи",
    "All files have been santized for Windows filename support." : "Пречишћени су сви фајлови тако да подржавају Windows захтеве за име фајла.",
    "Some files could not be sanitized, please check your logs." : "Неки фајлови нису могли да се пречисте, молимо вас да погледате дневнике.",
    "Sanitization errors" : "Грешке пречишћавања",
    "Not sanitized filenames" : "Имена фајлова који нису пречишћени",
    "Windows filename support has been enabled." : "Укључена је подршка за Windows имена фајлова.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Мада ово спречава да корисници креирају нове фајлове са именима која се не подржавају, постојећим фајловима још увек није промењено име, тако да још увек могу да покваре синхронизацију на Windows систему.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Можете да окинете промену имена фајлова који имају неисправно име, то ће се обавити у позадини и потрајаће неко време.",
    "Please note that this may cause high workload on the sync clients." : "Имајте на уму да ово може изазвати велико радно оптерећење на клијентима за синхронизацију.",
    "Limit" : "Граница",
    "This allows to configure how many users should be processed in one background job run." : "Ово вам омогућава да подесите број корисника који ће се обрадити у једном позадинском послу.",
    "Sanitize filenames" : "Пречисти имена фајлова",
    "(starting)" : "(почиње)",
    "Fill template fields" : "Попуните поља шаблона",
    "Submitting fields …" : "Поља се подносе …",
    "Submit" : "Пошаљи",
    "Choose a file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
    "Transfer" : "Пренеси",
    "Transfer {path} to {userid}" : "Пренеси {path} на корисника {userid}",
    "Invalid path selected" : "Одабрана неисправна путања",
    "Unknown error" : "Непозната грешка",
    "Ownership transfer request sent" : "Послат захтев за пренос власништва",
    "Cannot transfer ownership of a file or folder you do not own" : "Не можете да пренесете власништво над фајлом или фолдером који не поседујете",
    "Transfer ownership of a file or folder" : "Пренеси власништво фајла или фасцикле",
    "Choose file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
    "Change" : "Измени",
    "New owner" : "Нови власник",
    "Keep {old}" : "Задржи {old}",
    "Keep without extension" : "Задржи без екстензије",
    "Use {new}" : "Користи {new}",
    "Remove extension" : "Уклони екстензију фајла",
    "Change file extension" : "Промени екстензију фајла",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Ако екстензију „{old}” промените на „{new}” фајл може да постане нечитљив.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Ако уклоните екстензију „{old}” фајл може да постане нечитљив.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Ако додате екстензију „{new}” фајл може да постане нечитљив.",
    "Do not show this dialog again." : "Не приказуј поново овај дијалог.",
    "Select file or folder to link to" : "Изаберите фајл или фолдер на који показује линк",
    "Choose {file}" : "Изабери {file}",
    "Files settings" : "Подешавања фајлова",
    "Share" : "Пдели",
    "Shared by link" : "Дељени путем везе",
    "Shared" : "Подељено",
    "Switch to list view" : "Пређи на поглед листе",
    "Switch to grid view" : "Пређи на поглед мреже",
    "The file could not be found" : "Фајл није могао да се пронађе",
    "Upload was cancelled by user" : "Корисник је прекинуо отпремање",
    "Not enough free space" : "Нема довољно слободног места",
    "Operation is blocked by access control" : "Контрола приступа је блокирала операцију",
    "Error during upload: {message}" : "Грешка при отпремању: {message}",
    "Error during upload, status code {status}" : "Грешка приликом отпремања, кôд статуса {status}",
    "Unknown error during upload" : "Непозната грешка током отпремања",
    "Loading current folder" : "Учитавање текућег фолдера",
    "Retry" : "Покушај поново",
    "No files in here" : "Овде нема фајлова",
    "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
    "Go back" : "Иди назад",
    "Views" : "Прикази",
    "You" : "Ви",
    "Shared multiple times with different people" : "Дељено више пута са разним људима",
    "Unable to change the favorite state of the file" : "Није успела измена стања омиљено за фајл",
    "Error while loading the file data" : "Грешка при учитавању података фајла",
    "Owner" : "Власник",
    "Remove from favorites" : "Избаци из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "Tags" : "Ознаке",
    "Your files" : "Ваши фајлови",
    "Open in files" : "Отвори у фајловима",
    "File cannot be accessed" : "Фајлу не може да се приступи",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Фајл није могао да се пронађе или немате дозволу да га прегледате. Замолите пошиљаоца да га подели.",
    "No search results for “{query}”" : "Није нађен ниједан резултат за „{query}”",
    "Search for files" : "Претражи фајлове",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозвољава се ограничавање имена фајлова тако да сви клијенти могу да их синхронизују. Подразумевано се дозвољавају сва имена фајлова која су исправна на POSIX системима (нпр. Linux или macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Када се укључе Windows компатибилна имена фајлова, постојећи фајлови се више неће моћи мењати, али њихов власник може да им промени име на исправно ново име.",
    "Failed to toggle Windows filename support" : "Није успело укљ./искљ. подршке за Windows имена фајлова",
    "Files compatibility" : "Компатибилност фајлова",
    "Enforce Windows compatibility" : "Форсирај Windows компатибилност",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ово ће да блокира имена фајлова која су неисправна на Windows системима, као што су она која користе резервисана имена или специјалне карактере. Али ово неће форсирати компатибилност разликовања малих и великих слова.",
    "Blank" : "Празно",
    "Unable to create new file from template" : "Из шаблона није могао да се креира нови фајл",
    "Pick a template for {name}" : "Изаберите шаблон за {name}",
    "Create a new file with the selected template" : "Креирање новог фајла по изабраном шаблону",
    "Creating file" : "Креирање фајла",
    "Save as {displayName}" : "Сачувај као {displayName}",
    "Save as …" : "Сачувај као …",
    "Converting files …" : "Фајлови се конвертују …",
    "Failed to convert files: {message}" : "Није успела конверзија фајлова: {message}",
    "All files failed to be converted" : "Ниједан фајл није могао да се конвертује",
    "One file could not be converted: {message}" : "Један фајл није могао да се конвертује: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : [" %n фајл није могао да се конвертује"," %n фајла нису могла да се конвертују"," %n фајлова није могло да се конвертује"],
    "_%n file converted_::_%n files converted_" : ["конветован је %n фајл","конветована су %n фајла","конветовано је %n фајлова"],
    "Files converted" : "Конвертовано фајлова",
    "Failed to convert files" : "Није успела конверзија фајлова",
    "Converting file …" : "Фајл се конвертује …",
    "File successfully converted" : "Фајл је успешно конвертован",
    "Failed to convert file: {message}" : "Није успела конверзија фајла: {message}",
    "Failed to convert file" : "Фајл није могао да се конвертује",
    "Delete" : "Обриши",
    "Leave this share" : "Напусти ово дељење",
    "Leave these shares" : "Напусти ова дељења",
    "Disconnect storage" : "Искључи складиште",
    "Disconnect storages" : "Искључи складишта",
    "Delete permanently" : "Обриши заувек",
    "Delete and unshare" : "Обриши и прекини дељење",
    "Delete file" : "Обриши фајл",
    "Delete files" : "Обриши фајлове",
    "Delete folder" : "Обрши фолдер",
    "Delete folders" : "Обриши фолдере",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Управо ћете неповратно обрисати {count} ставку","Управо ћете неповратно обрисати {count} ставке","Управо ћете неповратно обрисати {count} ставки"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Управо ћете обрисати {count} ставку","Управо ћете обрисати {count} ставке","Управо ћете обрисати {count} ставки"],
    "Confirm deletion" : "Потврди брисање",
    "Cancel" : "Поништи",
    "Download" : "Преузми",
    "The requested file is not available." : "Тражени фајл није доступан.",
    "The requested files are not available." : "Тражени фајлови нису доступни.",
    "Add or remove favorite" : "Додај или уклони омиљене",
    "Moving \"{source}\" to \"{destination}\" …" : "„{source}” се премешта у „{destination}” …",
    "Copying \"{source}\" to \"{destination}\" …" : "„{source}” се копира у „{destination}” …",
    "Destination is not a folder" : "Одредиште није фолдер",
    "This file/folder is already in that directory" : "Овај фајл/фолдер се већ налази у том директоријуму",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Фајл/фолдер не можете да преместите у самог себе или у његов подфолдер",
    "(copy)" : "(копиран)",
    "(copy %n)" : "(копирано %n)",
    "A file or folder with that name already exists in this folder" : "У овом фолдеру већ постоји фајл или фолдер са тим именом",
    "The files are locked" : "Фајлови су закључани",
    "The file does not exist anymore" : "Фајл више не постоји",
    "Choose destination" : "Изаберите одредиште",
    "Copy to {target}" : "Копирај у {target}",
    "Copy" : "Копирај",
    "Move to {target}" : "Премести у {target}",
    "Move" : "Помери",
    "Move or copy operation failed" : "Није успела операција премештања или копирања",
    "Move or copy" : "Помери или копирај",
    "Open folder {displayName}" : "Отвори фолдер {displayName}",
    "Open in Files" : "Отвори у Фајловима",
    "Open locally" : "Отвори локално",
    "Failed to redirect to client" : "Преусмеравање на клијента није успело",
    "Open file locally" : "Отвори фајл локално",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Фајл би сада требало да се отвори на вашем уређају. Ако се не отвори, проверите да ли сте инсталирали декстоп апликацију.",
    "Retry and close" : "Покушај поново и затвори",
    "Open online" : "Отвори на мрежи",
    "Rename" : "Преименуј",
    "Details" : "Детаљи",
    "View in folder" : "Види у фасцикли",
    "Today" : "Данас",
    "Last 7 days" : "Последњих 7 дана",
    "Last 30 days" : "Последњих 30 дана",
    "This year ({year})" : "Ове године ({year})",
    "Last year ({year})" : "Прошле године ({year})",
    "Documents" : "Документи",
    "Spreadsheets" : "Табеле",
    "Presentations" : "Презентације",
    "PDFs" : "PDF фајлови",
    "Folders" : "Фолдери",
    "Audio" : "Звук",
    "Images" : "Слике",
    "Videos" : "Видео снимци",
    "Created new folder \"{name}\"" : "Креиран је нови фолдер „{name}”",
    "Unable to initialize the templates directory" : "Фолдер са шаблонима није могао да се иницијализује",
    "Create templates folder" : "Креирај фолдер шаблона",
    "Templates" : "Шаблони",
    "New template folder" : "Нови фолдер шаблона",
    "In folder" : "У фолдеру",
    "Search in all files" : "Претражи у свим фајловима",
    "Search in folder: {folder}" : "Претрага у фолдеру: {folder}",
    "One of the dropped files could not be processed" : "Један од упуштених фајлова не може да се обради",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш интернет прегледач не подржава Filesystem API. Нећете моћи да отпремате директоријуме",
    "No files to upload" : "Нема фајлова за отпремање",
    "Unable to create the directory {directory}" : "Не може да се креира директоријум {directory}",
    "Some files could not be uploaded" : "Неки фајлови нису могли да се отпреме",
    "Files uploaded successfully" : "Фајлови су успешно отремљени",
    "No files to process" : "Нема фајлова за обраду",
    "Some files could not be copied" : "Неки фајлови нису могли да се копирају",
    "Some files could not be moved" : "Неке фајлове нисам могао да преместим",
    "Files copied successfully" : "Фајлови су успешно копирани",
    "Files moved successfully" : "Фајлови су успешно премештени",
    "Conflicts resolution skipped" : "Прексочено је разрешавање конфилката",
    "Upload cancelled" : "Отпремање је отказано",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не може да се промени име фајла „{oldName}” јер фајл више не постоји",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{newName}” се већ користи у директоријуму „{dir}”. Молимо вас да изаберете неко друго име.",
    "Could not rename \"{oldName}\"" : "Не може да се промени име фајла „{oldName}”",
    "This operation is forbidden" : "Ова радња је забрањена",
    "This folder is unavailable, please try again later or contact the administration" : "Овај фолдер није доступан, молимо вас да покушате касније или да контактирате администрацију",
    "Storage is temporarily not available" : "Складиште привремено није  доступно",
    "Unexpected error: {error}" : "Неочекивана грешка: {error}",
    "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
    "_%n folder_::_%n folders_" : ["%n фасцикла","%n фасцикле","%n фасцикли"],
    "_%n hidden_::_%n hidden_" : ["%n скривен","%n скривена","%n скривених"],
    "Filename must not be empty." : "Назив фајла не може бити празан.",
    "\"{char}\" is not allowed inside a filename." : "„{char}“ није дозвољен карактер у имену фајла.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "„{segment}” је резервисано име и не сме се користити као име фајла.",
    "\"{extension}\" is not an allowed filetype." : "„{extension}” није дозвољени тип фајла.",
    "Filenames must not end with \"{extension}\"." : "Имена фајлова не смеју да се завршавају са „{extension}”.",
    "List of favorite files and folders." : "Листа омиљених фајлова и фолдера.",
    "No favorites yet" : "Још нема омиљених",
    "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
    "List of your files and folders." : "Листа ваших фајлова и фолдера.",
    "Folder tree" : "Стабло фолдера",
    "List of your files and folders that are not shared." : "Листа ваших фајлова и фолдера који се не деле.",
    "No personal files found" : "Није пронађен ниједан лични фајл",
    "Files that are not shared will show up here." : "Овде ће се појавити фајлови који се не деле.",
    "Recent" : "Скорашњи",
    "List of recently modified files and folders." : "Листа фајлова и директоријума који су недавно измењени.",
    "No recently modified files" : "Нема недавно промењених фајлова",
    "Files and folders you recently modified will show up here." : "Овде ће се појавити фајлови и фолдери које сте недавно изменили.",
    "Search" : "Претрага",
    "Search results within your files." : "Претрага резултата у вашим фајловима.",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Select all" : "Означи све",
    "Upload too large" : "Отпремање је превелико",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
    "%1$s (renamed)" : "%1$s (преименован)",
    "renamed file" : "преименован фајл",
    "Upload (max. %s)" : "Отпремање (макс. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Када се укључе windows компатибилна имена фајлова, постојећи фајлови се више неће моћи мењати, али њихов власник може да им промени име на исправно ново име.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Фајлови такође могу аутоматски да се мигрирају након укључивања овог подешавања, молимо вас да погледате документацију у вези са occ командом.",
    "\"{displayName}\" failed on some elements" : "„{displayName}” није успело на неким елементима",
    "\"{displayName}\" batch action executed successfully" : "Пакетна акција „{displayName}” се успешно извршила",
    "\"{displayName}\" action failed" : "Акција „{displayName}” није успела",
    "Submitting fields …" : "Поља се подносе…",
    "\"{displayName}\" action executed successfully" : "Акција „{displayName}” је успешно извршена",
    "Filter file names …" : "Филтрирање имена фајлова…",
    "Clipboard is not available" : "Клипборд није доступан",
    "WebDAV URL copied to clipboard" : "WebDAV URL је копиран у клипборд",
    "Enable the grid view" : "Укључи приказ мреже",
    "Enable folder tree" : "Укључи стабло фолдера",
    "WebDAV" : "ВебДАВ",
    "Copy to clipboard" : "Копирај у оставу",
    "Use this address to access your Files via WebDAV" : "Користи ову адресу да приступате Вашим фајловима преко ВебДАВа",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако сте укључили 2FA, морате кликом овде да крерате нову лозинку апликације.",
    "Prevent warning dialogs from open or reenable them." : "Спречава да се дијалози упозорења отворе или да се поново укључе.",
    "Show a warning dialog when changing a file extension." : "Прикажи дијалог упозорења када се мења екстензија фајла.",
    "Keyboard shortcuts" : "Пречице на тастатури",
    "Speed up your Files experience with these quick shortcuts." : "Убрзајте рад у апликацији Фајлови следећим брзим пречицама.",
    "Open the actions menu for a file" : "Отвори мени са акцијама над фајлом",
    "Rename a file" : "Промени име фајла",
    "Delete a file" : "Обриши фајл",
    "Favorite or remove a file from favorites" : "Постави или уклони из омиљених",
    "Manage tags for a file" : "Управљај ознакама фајла",
    "Deselect all files" : "Уклони избор са свих фајлова",
    "Select or deselect a file" : "Изабери фајл или уклони избор фајла",
    "Select a range of files" : "Изабери опсег фајлова",
    "Navigate to the parent folder" : "Пређи на фолдер родитељ",
    "Navigate to the file above" : "Пређи на фајл изнад",
    "Navigate to the file below" : "Пређи на фајл испод",
    "Navigate to the file on the left (in grid mode)" : "Пређи на фајл са леве стране (у режиму мреже)",
    "Navigate to the file on the right (in grid mode)" : "Пређи на фајл са десне стране (у режиму мреже)",
    "Toggle the grid view" : "Укључи/искључи приказ мреже",
    "Open the sidebar for a file" : "Отвори у бочни панел за фајл",
    "Save as …" : "Сачувај као",
    "Converting files …" : "Фајлови се конвертују",
    "Converting file …" : "Фајл се конвертује",
    "Deletion cancelled" : "Брисање је отказано",
    "Edit locally" : "Уреди локално",
    "Moving \"{source}\" to \"{destination}\" …" : "„{source}” се премешта у „{destination}”…",
    "Copying \"{source}\" to \"{destination}\" …" : "„{source}” се копира у „{destination}”…",
    "Move cancelled" : "Премештање је отказано",
    "Cancelled move or copy of \"{filename}\"." : "Операција премештања или копирања „{filename}” је отказана.",
    "Cancelled move or copy operation" : "Операција премештања или копирања је отказана",
    "Open details" : "Отвори детаље",
    "Photos and images" : "Фотографије и слике",
    "New folder creation cancelled" : "Отказане је креирање новог фолдера",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите дневник или контактирајте администратора",
    "All folders" : "Сви фолдери",
    "Search everywhere …" : "Претражи свуда",
    "Search here …" : "Претражи овде…",
    "Preparing …" : "Припрема се синхронизација"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
